#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Script to create Figure S2 (control) from Glade, Shobe, Anderson, and Tucker, 
which consists of 10-year and 1000-year channel and hillslope erosion rates 
from three different places in the landscape.

Authors: Charlie Shobe and Rachel Glade, University of Colorado

Software: Python 2.7, Numpy, MatPlotLib
"""
#imports
from __future__ import division
import numpy as np
import matplotlib.pyplot as plt
import matplotlib
matplotlib.rcParams.update({'font.size': 14})

##run and data parameters#####################################################
t_start = 0 # years
t_end = 1000000 #yr
dt = 2 #years
end_x_axis = 250
bl_rate = 0.1 #mm/yr
imposed_e_rate = bl_rate / 1000
last_year = 56998 #years
load_time_range = np.arange(0, last_year + dt, dt)
t = np.arange(t_start, t_end, dt) / 1000.
t_between = np.arange(t_start+1, t_end-1, dt) / 1000.
num_channel_nodes = 199
time_indices = np.arange(10000, 500000 + 10000, 10000)

##load channel data and calculate erosion rates###############################
data_lower = np.load('channel_elevation_timeseries_lower_node.npy')
data_lower = data_lower[0:125000] #since dt=2 yrs, this caps series at 250 kyr

data_middle = np.load('channel_elevation_timeseries_middle_node.npy')
data_middle = data_middle[0:125000]

data_upper = np.load('channel_elevation_timeseries_upper_node.npy')
data_upper = data_upper[0:125000]

data = np.column_stack((data_lower, data_middle, data_upper))
channel_e_magnitudes = -np.diff(data, axis=0)
channel_e_rates = channel_e_magnitudes / dt #m/yr

ratio = channel_e_rates / imposed_e_rate #normalize to impose bl lowering

##load hillslope data and calcuate erosion rates###############################
down = np.load('hillslope_elevation_timeseries_lower_node.npy')
mid = np.load('hillslope_elevation_timeseries_middle_node.npy')
up = np.load('hillslope_elevation_timeseries_upper_node.npy')

norm_rate_down = -(np.diff(down)/2)/imposed_e_rate #[-]
norm_rate_mid = -(np.diff(mid)/2)/imposed_e_rate
norm_rate_up = -(np.diff(up)/2)/imposed_e_rate

##take moving window averages of hillslope erosion rates#######################
#lower node
#10 year moving window
down_10yr_moving_window = np.zeros(len(norm_rate_down))
for i in range(2, len(down) - 2):
	down_10yr_moving_window[i] = np.mean(norm_rate_down[i-2:i+2])

#1000 year moving window
down_1000yr_moving_window = np.zeros(len(norm_rate_down))
for i in range(240, len(down) - 240):
	down_1000yr_moving_window[i] = np.mean(norm_rate_down[i-240:i+240])

#middle node
#10 year moving window
mid_10yr_moving_window = np.zeros(len(norm_rate_mid))
for i in range(2, len(mid) - 2):
	mid_10yr_moving_window[i] = np.mean(norm_rate_mid[i-2:i+2])

#1000 year moving window
mid_1000yr_moving_window = np.zeros(len(norm_rate_mid))
for i in range(240, len(mid) - 240):
	mid_1000yr_moving_window[i] = np.mean(norm_rate_mid[i-240:i+240])

#upper node
#10 year moving window
up_10yr_moving_window = np.zeros(len(norm_rate_up))
for i in range(2, len(up) - 2):
	up_10yr_moving_window[i] = np.mean(norm_rate_up[i-2:i+2])

#1000 year moving window
up_1000yr_moving_window = np.zeros(len(norm_rate_up))
for i in range(240, len(up) - 240):
	up_1000yr_moving_window[i] = np.mean(norm_rate_up[i-240:i+240])

##take moving window averages of channel erosion rates#######################

#lower node
#10 year moving window
down_ratio_10yr_moving_window = np.zeros(len(ratio[:, 0]))
for i in range(2, len(ratio[:, 0]) - 2):
	down_ratio_10yr_moving_window[i] = np.mean(ratio[i-2:i+2, 0])

#1000 year moving window
down_ratio_1000yr_moving_window = np.zeros(len(ratio[:, 0]))
for i in range(240, len(ratio[:, 0]) - 240):
	down_ratio_1000yr_moving_window[i] = np.mean(ratio[i-240:i+240, 0])

#middle node
#10 year moving window
mid_ratio_10yr_moving_window = np.zeros(len(ratio[:, 1]))
for i in range(2, len(ratio[:, 1]) - 2):
	mid_ratio_10yr_moving_window[i] = np.mean(ratio[i-2:i+2, 1])

#1000 year moving window
mid_ratio_1000yr_moving_window = np.zeros(len(ratio[:, 1]))
for i in range(240, len(ratio[:, 1]) - 240):
	mid_ratio_1000yr_moving_window[i] = np.mean(ratio[i-240:i+240, 1])
    
#upper node
#10 year moving window
up_ratio_10yr_moving_window = np.zeros(len(ratio[:, 2]))
for i in range(2, len(ratio[:, 2]) - 2):
	up_ratio_10yr_moving_window[i] = np.mean(ratio[i-2:i+2, 2])

#1000 year moving window
up_ratio_1000yr_moving_window = np.zeros(len(ratio[:, 2]))
for i in range(240, len(ratio[:, 2]) - 240):
	up_ratio_1000yr_moving_window[i] = np.mean(ratio[i-240:i+240, 2])

##setup plots################################################################
#setup figure and subplots
fig = plt.figure(figsize = (8,8))

#channel erosion rate plots: left column
chan_e_rate_plot1 = plt.subplot(3,1,1)
chan_e_rate_plot2 = plt.subplot(3,1,2)
chan_e_rate_plot3 = plt.subplot(3,1,3)

##make bottom plot (plot 3)######################################################

#plot channel erosion rates on left y-axis
chan_e_rate_plot3.plot(t_between[0:124999], down_ratio_10yr_moving_window[0:124999], color='lightcoral', alpha=1, zorder=1)
chan_e_rate_plot3.plot(t_between[0:124999], down_ratio_1000yr_moving_window[0:124999], color='maroon', zorder=3)
chan_e_rate_plot3.axhline(1, linestyle='--', color='k')
chan_e_rate_plot3.set_xlim(0, end_x_axis)
chan_e_rate_plot3.set_ylim(0, 12)
ticks = chan_e_rate_plot3.get_yticks()
chan_e_rate_plot3.set_yticks(np.array([0, 3, 6]))
chan_e_rate_plot3.tick_params(
    axis='both',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    direction='out') # labels along the bottom edge are off
chan_e_rate_plot3.tick_params('y', colors='maroon')
chan_e_rate_plot3.set_xlabel('Time [kyr]')
chan_e_rate_plot3.set_ylabel(r'$\varepsilon_c/\varepsilon_0$', color='maroon', position=(0,0.25))

#plot hillslope erosion rates on right y-axis
hill_e_rate_plot3 = chan_e_rate_plot3.twinx()
hill_e_rate_plot3.plot(t[0:124999], down_10yr_moving_window[0:124999], '0.7', zorder=1)
hill_e_rate_plot3.plot(t[0:124999], down_1000yr_moving_window[0:124999], 'k', zorder=3)
hill_e_rate_plot3.axhline(1, linestyle='--', color='k')
hill_e_rate_plot3.set_xlim(0, end_x_axis)
hill_e_rate_plot3.set_ylim(-8,5)
hill_e_rate_plot3.set_ylabel(r'$\varepsilon_h/\varepsilon_0$', color='k', position=(0.97,0.62))
hill_e_rate_plot3.yaxis.set_label_coords(1.04, 0.62, transform=None)
hill_e_rate_plot3.tick_params('y', colors='k')
hill_e_rate_plot3.set_yticks(np.array([-5, 0, 5]))

chan_e_rate_plot3.set_zorder(hill_e_rate_plot3.get_zorder()+1)
chan_e_rate_plot3.patch.set_visible(False)

##make middle plot (plot 2)######################################################

#plot channel erosion rates on left y-axis
chan_e_rate_plot2.plot(t_between[0:124999], mid_ratio_10yr_moving_window[0:124999], color='lightcoral', alpha=1, zorder=1)
chan_e_rate_plot2.plot(t_between[0:124999], mid_ratio_1000yr_moving_window[0:124999], color='maroon', zorder=3)
chan_e_rate_plot2.axhline(1, linestyle='--', color='k')
chan_e_rate_plot2.set_xlim(0, end_x_axis)
chan_e_rate_plot2.set_ylim(0, 12)
ticks = chan_e_rate_plot2.get_yticks()
chan_e_rate_plot2.set_yticks(np.array([0, 3, 6]))
chan_e_rate_plot2.tick_params(
    axis='both',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    direction='out',
    labelbottom=False) # labels along the bottom edge are off
chan_e_rate_plot2.tick_params('y', colors='maroon')
chan_e_rate_plot2.set_ylabel(r'$\varepsilon_c/\varepsilon_0$', color='maroon', position=(0,0.25))

#plot hillslope erosion rates on right y-axis
hill_e_rate_plot2 = chan_e_rate_plot2.twinx()
hill_e_rate_plot2.plot(t[0:124999], mid_10yr_moving_window[0:124999], '0.7', zorder = 1)
hill_e_rate_plot2.plot(t[0:124999], mid_1000yr_moving_window[0:124999], 'k', zorder=3)
hill_e_rate_plot2.axhline(1, linestyle='--', color='k')
hill_e_rate_plot2.set_xlim(0, end_x_axis)
hill_e_rate_plot2.set_ylim(-8,5)
hill_e_rate_plot2.set_ylabel(r'$\varepsilon_h/\varepsilon_0$', color='k', position=(0.97,0.62))
hill_e_rate_plot2.yaxis.set_label_coords(1.04, 0.62, transform=None)
hill_e_rate_plot2.tick_params('y', colors='k')
hill_e_rate_plot2.set_yticks(np.array([-5, 0, 5]))
hill_e_rate_plot2.tick_params(
    axis='both',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    direction='out',
    labelbottom=False) # labels along the bottom edge are off

chan_e_rate_plot2.set_zorder(hill_e_rate_plot2.get_zorder()+1)
chan_e_rate_plot2.patch.set_visible(False)

##make top plot (plot 1)######################################################

#plot channel erosion rates on left y-axis
chan_e_rate_plot1.plot(t_between[0:124999], up_ratio_10yr_moving_window[0:124999], color='lightcoral', alpha=1, zorder=1)
chan_e_rate_plot1.plot(t_between[0:124999], up_ratio_1000yr_moving_window[0:124999], color='maroon', zorder=3)
chan_e_rate_plot1.axhline(1, linestyle='--', color='k')
chan_e_rate_plot1.set_xlim(0, end_x_axis)
chan_e_rate_plot1.set_ylim(0, 12)
ticks = chan_e_rate_plot1.get_yticks()
chan_e_rate_plot1.set_yticks(np.array([0, 3, 6]))
chan_e_rate_plot1.tick_params(
    axis='both',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    direction='out',
    labelbottom=False) # labels along the bottom edge are off
chan_e_rate_plot1.tick_params('y', colors='maroon')
chan_e_rate_plot1.set_ylabel(r'$\varepsilon_c/\varepsilon_0$', color='maroon', position=(0,0.25))

#plot hillslope erosion rates on right y-axis
hill_e_rate_plot1 = chan_e_rate_plot1.twinx()
hill_e_rate_plot1.plot(t[0:124999], up_10yr_moving_window[0:124999], '0.7', zorder=1)
hill_e_rate_plot1.plot(t[0:124999], up_1000yr_moving_window[0:124999], 'k', zorder=3)
hill_e_rate_plot1.axhline(1, linestyle='--', color='k')
hill_e_rate_plot1.set_xlim(0, end_x_axis)
hill_e_rate_plot1.set_ylim(-8,5)
hill_e_rate_plot1.set_ylabel(r'$\varepsilon_h/\varepsilon_0$', color='k', position=(0.97,0.62))
hill_e_rate_plot1.yaxis.set_label_coords(1.04, 0.62, transform=None)
hill_e_rate_plot1.tick_params('y', colors='k')
hill_e_rate_plot1.set_yticks(np.array([-5, 0, 5]))
hill_e_rate_plot1.tick_params(
    axis='both',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    direction='out',
    labelbottom=False)

chan_e_rate_plot1.set_zorder(hill_e_rate_plot1.get_zorder()+1)
chan_e_rate_plot1.patch.set_visible(False)

##finish up and save##########################################################
hill_e_rate_plot1.text(-50, 2.0, '600 meters \n upstream')
hill_e_rate_plot2.text(-50, 2.0, '300 meters \n upstream')
hill_e_rate_plot3.text(-50, 2.0, 'Adjacent to \n baselevel')
plt.tight_layout()
fig.savefig('control_point1_meter_erosion.eps', dpi=1000)